@@ -25,8 +25,8 @@ class Resensys():
             'password': self.encoded_password,
             'host': self.host,
             'port': 3306,
-            'tls_versions':['TLSv1.2']
-            # 'ssl_disabled': True,
+            # 'tls_versions':['TLSv1.1']
+            'ssl_disabled': True,
 
             # Create SSL connection with the self-signed certificate
             # 'ssl_verify_cert': False,
